@@ -1,4 +1,5 @@
 """SatNOGS DB API django rest framework Views"""
+from django.conf import settings
 from django.core.files.base import ContentFile
 from django.db.models import F
 from drf_spectacular.types import OpenApiTypes
@@ -227,15 +228,15 @@ class TelemetryViewSet(  # pylint: disable=R0901
         """
         data = {}
 
-        norad_cat_id = request.data.get('noradID')
+        norad_id = request.data.get('noradID')
 
-        if not Satellite.objects.filter(norad_cat_id=norad_cat_id).exists():
+        if not Satellite.objects.filter(norad_cat_id=norad_id).exists():
             try:
-                update_satellite(norad_cat_id, update_name=True)
+                update_satellite(norad_id, update_name=True)
             except LookupError:
                 return Response(status=status.HTTP_400_BAD_REQUEST)
 
-        data['satellite'] = Satellite.objects.get(norad_cat_id=norad_cat_id).id
+        data['satellite'] = Satellite.objects.get(norad_cat_id=norad_id).id
         data['station'] = request.data.get('source')
         timestamp = request.data.get('timestamp')
         data['timestamp'] = timestamp
@@ -245,6 +246,10 @@ class TelemetryViewSet(  # pylint: disable=R0901
         if request.data.get('observation_id'):
             observation_id = request.data.get('observation_id')
             data['observation_id'] = observation_id
+        station_id = ''
+        if request.data.get('station_id'):
+            station_id = request.data.get('station_id')
+            data['station_id'] = station_id
 
         # Convert coordinates to omit N-S and W-E designators
         lat = request.data.get('latitude')
@@ -277,12 +282,17 @@ class TelemetryViewSet(  # pylint: disable=R0901
         self.perform_create(serializer)
 
         # Run task to decode the current frame
-        decode_current_frame.delay(norad_cat_id, serializer.instance.pk)
+        decode_current_frame.delay(norad_id, serializer.instance.pk)
 
         # Run task to publish the current frame via ZeroMQ
-        publish_current_frame.delay(
-            norad_cat_id, timestamp, request.data.get('frame'), observer, observation_id
-        )
+        if settings.ZEROMQ_ENABLE:
+            publish_current_frame.delay(
+                timestamp, request.data.get('frame'), observer, {
+                    'norad_id': norad_id,
+                    'observation_id': observation_id,
+                    'station_id': station_id
+                }
+            )
 
         return Response(status=status.HTTP_201_CREATED)
 
