@@ -281,8 +281,10 @@ class TelemetryAdmin(admin.ModelAdmin):
 @admin.register(DemodData)
 class DemodDataAdmin(admin.ModelAdmin):
     """Defines DemodData view in django admin UI"""
-    list_display = ('id', 'satellite', 'app_source', 'observer', 'observation_id')
-    search_fields = ('transmitter__uuid', 'satellite__norad_cat_id', 'observer', 'observation_id')
+    list_display = ('id', 'satellite', 'app_source', 'observer', 'observation_id', 'station_id')
+    search_fields = (
+        'transmitter__uuid', 'satellite__norad_cat_id', 'observer', 'observation_id', 'station_id'
+    )
     list_filter = (
         'satellite',
         'app_source',
