@@ -11,26 +11,23 @@ def existing_uuid(value):
     """ensures the UUID is existing and valid"""
     try:
         Transmitter.objects.get(uuid=value)
-    except Transmitter.DoesNotExist:
+    except Transmitter.DoesNotExist as error:
         raise ValidationError(
             _('%(value)s is not a valid uuid'),
             code='invalid',
             params={'value': value},
-        )
+        ) from error
 
 
 class TransmitterModelForm(BSModalModelForm):  # pylint: disable=too-many-ancestors
     """Model Form class for TransmitterEntry objects"""
     class Meta:
         model = TransmitterEntry
-        # yapf: disable
         fields = [
             'description', 'type', 'status', 'uplink_low', 'uplink_high', 'uplink_drift',
-            'uplink_mode', 'downlink_low', 'downlink_high', 'downlink_drift',
-            'downlink_mode', 'invert', 'baud', 'citation', 'service', 'coordination',
-            'coordination_url'
+            'uplink_mode', 'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode',
+            'invert', 'baud', 'citation', 'service', 'coordination', 'coordination_url'
         ]
-        # yapf: enable
         labels = {
             'downlink_low': _('Downlink freq.'),
             'uplink_low': _('Uplink freq.'),
@@ -45,14 +42,11 @@ class TransmitterUpdateForm(BSModalModelForm):  # pylint: disable=too-many-ances
     """Model Form class for TransmitterEntry objects"""
     class Meta:
         model = TransmitterEntry
-        # yapf: disable
         fields = [
             'description', 'type', 'status', 'uplink_low', 'uplink_high', 'uplink_drift',
-            'uplink_mode', 'downlink_low', 'downlink_high', 'downlink_drift',
-            'downlink_mode', 'invert', 'baud', 'citation', 'service', 'coordination',
-            'coordination_url', 'created'
+            'uplink_mode', 'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode',
+            'invert', 'baud', 'citation', 'service', 'coordination', 'coordination_url', 'created'
         ]
-        # yapf: enable
         labels = {
             'downlink_low': _('Downlink freq.'),
             'uplink_low': _('Uplink freq.'),
