@@ -13,7 +13,7 @@ from django.core.exceptions import ObjectDoesNotExist
 from django.core.paginator import Paginator
 from django.db import OperationalError
 from django.db.models import Count, Max, Prefetch, Q
-from django.http import HttpResponse, JsonResponse
+from django.http import HttpResponse, HttpResponseServerError, JsonResponse
 from django.shortcuts import get_object_or_404, redirect, render
 from django.urls import reverse
 from django.utils import timezone
@@ -332,8 +332,11 @@ def recent_decoded_cnt(request, norad):
 
     :returns: JSON of point counts as JsonResponse
     """
-    results = read_influx(norad)
-    return JsonResponse(results, safe=False)
+    if settings.USE_INFLUX:
+        results = read_influx(norad)
+        return JsonResponse(results, safe=False)
+
+    return HttpResponseServerError()
 
 
 class TransmitterCreateView(LoginRequiredMixin, BSModalCreateView):
