@@ -5,6 +5,7 @@ from django.conf.urls import include
 from django.contrib import admin
 from django.urls import path
 from django.views.static import serve
+from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerSplitView
 
 from db.api.urls import API_URLPATTERNS
 from db.base.urls import BASE_URLPATTERNS
@@ -19,6 +20,12 @@ urlpatterns = [
     # API
     path('api/', include(API_URLPATTERNS)),
 
+    # API Schema
+    path('api/schema/', SpectacularAPIView.as_view(), name='schema'),
+    # Swagger UI view of our schema. Note the use of SpectacularSwaggerSplitView
+    # is to avoid CSP issues without having to open up unsafe-inline.
+    path('api/schema/docs/', SpectacularSwaggerSplitView.as_view(url_name='schema'), name='docs'),
+
     # Admin
     path('admin/', admin.site.urls),
 ]
